@@ -139,6 +139,9 @@ class ClInstallAction(Action):
          'condition': lambda dv: dv.Get('cl_target') and dv.Get(
              'cl_target').childs,
          'depend': Tasks.has("unpack")},
+        {'name': 'check success configure',
+         'method': 'Install.check_success_configure()',
+         },
         # вывести сообщение в случае успеха
         {'name': 'success',
          'message': __("System successfully installed!")},
